package de.intevation.gnv.action.mapviewer.parser;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Collection;
import java.util.Iterator;

import junit.framework.TestCase;

import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Logger;

import de.intevation.gnv.artifactdatabase.objects.map.Layer;
import de.intevation.gnv.artifactdatabase.objects.map.MapService;

public class ExternalCallParserTestCase extends TestCase {
    
    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = null;

    static {
        BasicConfigurator.configure();
        log = Logger.getLogger(ExternalCallParserTestCase.class);
    }
    
    public ExternalCallParserTestCase() {
        super();
    }

    public ExternalCallParserTestCase(String name) {
        super(name);
    }
    
    public void testParseExternalCall() {
        log.debug("Execute testParseExternalCall");
        try {
            InputStream inputStream = new FileInputStream(
                    new File("src/test/ressources/externalinterfacecall.xml"));
           ExternalCallParser ecp = new XMLExternalCallParser(inputStream);
           ecp.parse();
           String geometry = ecp.getGeometry();
           assertNotNull(geometry);
           log.debug("Parsed Geometry: "+geometry);
           String srs = ecp.getSRS();
           assertNotNull(srs);
           log.debug("Parsed SRS: "+srs);
           Collection<MapService> mapServices = ecp.getMapServices();
           assertNotNull(mapServices);
           log.debug(mapServices.size()+"Mapservices parsed");
           assertEquals(2, mapServices.size());
           Iterator<MapService> it = mapServices.iterator();
           MapService mapService1 = it.next();
           MapService mapService2 = it.next();
           
           log.debug("MapService 1");
           log.debug("ID: "+mapService1.getID());
           log.debug("URL: "+mapService1.getURL());
           log.debug("TYPE: "+mapService1.getType());
           Collection<Layer> layer1 = mapService1.getLayer();
           log.debug("Layer parsed: "+layer1.size());
           assertEquals(5, layer1.size());
           Iterator<Layer> layerIt1 = layer1.iterator();
           while(layerIt1.hasNext()){
               log.debug(layerIt1.next().toString());
           }
           
           log.debug("MapService 2");
           log.debug("ID: "+mapService2.getID());
           log.debug("URL: "+mapService2.getURL());
           log.debug("TYPE: "+mapService2.getType());
           Collection<Layer> layer2 = mapService2.getLayer();
           log.debug("Layer parsed: "+layer2.size());
           assertEquals(2, layer2.size());
           Iterator<Layer> layerIt2 = layer2.iterator();
           while(layerIt2.hasNext()){
               log.debug(layerIt2.next().toString());
           }
           
        } catch (Exception e) {
            log.error(e,e);
            fail();
        }
        
    }

}
